@@ -48,13 +48,28 @@ test_that("wbt initialization [WhiteboxTools missing]", {
   if (sysbak != "") Sys.setenv("R_WHITEBOX_EXE_PATH" = sysbak)
 })
 
-test_that("wbt working directories", {
+test_that("wbt path expansion", {
+  dem <- as.character(wbt_file_path("~/dem.tif", shell_quote = FALSE)) 
+  dem3a <- as.character(wbt_file_path("~/dem1.tif;~/dem2.tif;~/dem3.tif"))
+  dem3b <- as.character(wbt_file_path("~/dem1.tif,~/dem2.tif,~/dem3.tif"))
+  expect_equal(dem, file.path(path.expand("~"), "dem.tif"))
+  
+  
+  expect_equal(dem3a, shQuote(paste0(file.path(path.expand("~"), 
+                                     sprintf("dem%s.tif", 1:3)), 
+                                     collapse = ",")))
+  expect_equal(dem3a, dem3b)
+})
+
+test_that("wbt setting and using working directories", {
   
   skip_on_cran()
   
   skip_if_not(check_whitebox_binary())
   
-  dem <- whitebox:::sample_dem_data()
+  dem <- sample_dem_data()
+  
+  skip_if(dem == "")
   
   tf <- tempfile(fileext = ".tif")
   
@@ -93,6 +108,13 @@ test_that("wbt working directories", {
   
   # cleanup
   unlink(tf)
+})
+
+test_that("wbt reset working directory", {
+  
+  skip_on_cran()
+  
+  skip_if_not(check_whitebox_binary())
   
   ## RESETTING A WORKING DIRECTORY (unset attribute of whitebox.wd)
   
@@ -164,6 +186,26 @@ test_that("wbt utility functions [requires WhiteboxTools installed]", {
   expect_true(is.character(wbt_tool_help()))
 })
 
+test_that("wbt raster compression", {
+  
+  skip_on_cran()
+  
+  skip_if_not(check_whitebox_binary())
+  
+  dem <- sample_dem_data()
+  
+  skip_if(dem == "")
+  
+  wbt_geomorphons(sample_dem_data(), output = "test_compressed.tif", compress_rasters = TRUE)
+  
+  wbt_geomorphons(sample_dem_data(), output = "test_no-compress.tif", compress_rasters = FALSE)
+  
+  expect_true(file.size("test_compressed.tif") < file.size("test_no-compress.tif"))
+  
+  unlink(c("test_compressed.tif", "test_no-compress.tif"))
+  
+})
+
 test_that("wbt tool name cleaning", {
   
   # wbt_internal_tool_name(): The internal tool name method is a single place for "name cleaning" to happen so it is standard. It deals with some of the messiness with converting between R function names and WBT tool names.
@@ -175,11 +217,11 @@ test_that("wbt tool name cleaning", {
   # commands generated from match.call() on `whitebox::wbt_wetness_index()`
   #  should match command for a pre-cleaned tool name "wetness_index"
   expect_equal(
-    whitebox::wbt_run_tool("--dem=foo.tif --output=bar.tif",
+    wbt_run_tool("--dem=foo.tif --output=bar.tif",
       tool_name = c("::", "whitebox", "wbt_wetness_index"),
       command_only = TRUE
     ),
-    whitebox:::wbt_system_call(
+    wbt_system_call(
       "--dem=foo.tif --output=bar.tif -v",
       tool_name = "wetness_index",
       command_only = TRUE
